@@ -68,8 +68,6 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax vagy webcron mód érzékelve! A folyamaid nem lesznek frissítve!",
     "How to set up the operating system cron" : "Hogyan állítsd be az operációs rendszer időzítőjét",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Új gyorsabb, párhuzamosított frissítő telepítése, mely a hírek app API-ját használja",
-    "Non UTF-8 charset for MySQL/MariaDB database detected!" : "Nem UTF-8 karakterkészlet észlelve a MySQL/MariaDB adatbázisban!",
-    "Learn how to convert your database to utf8mb4 (make a backup beforehand)" : "Ismerd meg hogyan alakíthatod az adatbázisodat uft8mb4-re (előtte készíts biztonsági mentést)",
     "Web address" : "Web cím",
     "Feed exists already!" : "A hírfolyam már létezik!",
     "Folder" : "Mappa",
