@@ -68,8 +68,6 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Bol zistený ajax alebo webcron mód. Vaše kanály sa nebudú aktualizovať!",
     "How to set up the operating system cron" : "Ako nastaviť cron v operačnom systéme",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Nainštalovať a nastaviť rýchlejší paralelný systém aktualizácie používajúci aktualizačné API modulu Noviniek",
-    "Non UTF-8 charset for MySQL/MariaDB database detected!" : "Bolo zistené MySQL/MariaDB so znakovou sadou inou než UTF-8!",
-    "Learn how to convert your database to utf8mb4 (make a backup beforehand)" : "Naučte sa, ako konvertovať databázu do utf8mb4 (najprv vykonajte zálohu)",
     "Web address" : "Web adresa",
     "Feed exists already!" : "Kanál už existuje!",
     "Folder" : "Priečinok",
