@@ -8,7 +8,7 @@ OC.L10N.register(
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interna napaka strežnika! Preveri data/nextcloud.log datoteko za dodatne informacije!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva ni uspela, Nextcloud je trenutno v servisnem načinu!",
     "Can not add feed: Exists already" : "Vira ni mogoče dodati: ta že obstaja",
-    "Articles without feed" : "Članki brez virov",
+    "Articles without feed" : "Prispevki brez virov",
     "Can not add folder: Exists already" : "Ni mogoče dodati mape: mapa že obstaja.",
     "News" : "Novice",
     "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
     "Focus search field" : "Postavi iskalno polje v žarišče",
     "Mark current article's feed/folder read" : "Označi trenutni predmet kot prebran",
+    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zaznan je način Ajax oziroma webcron! Izbrani viri ne bodo posodobljeni!",
     "How to set up the operating system cron" : "Kako nastaviti opravila cron operacijskega sistema",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti in nastavi hitrejši vzporedni posodabljalnik, ki za posodobitev uporablja  API programa  News",
     "Web address" : "Spletni naslov",
