@@ -12,6 +12,10 @@
         <p ng-show="Content.isShowAll()"><?php p($l->t('No articles available')) ?></p>
         <p ng-show="!Content.isShowAll()"><?php p($l->t('No unread articles available')) ?></p>
     </div>
+    <button ng-controller="NavigationController as Navigation" id="mark-all-read-button" ng-click="Navigation.markCurrentRead()" class="hidden">
+        <span title="Mark Read" class="icon-checkmark"></span>
+    </button>
+
     <ul>
         <li class="item {{ ::Content.getFeed(item.feedId).cssClass }}"
             ng-repeat="item in Content.getItems() |
@@ -87,7 +91,7 @@
                     <li class="util more" news-stop-propagation ng-hide="noPlugins">
                         <button class="icon-more" news-toggle-show="#actions-{{item.id}}"></button>
                         <div class="article-actions" id="actions-{{item.id}}">
-                            <ul news-article-actions="item" no-plugins="noPlugins"><ul>
+                            <ul news-article-actions="item" no-plugins="noPlugins"></ul>
                         </div>
                     </li>
                 </ul>
